"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.stringify = stringify;
exports.applySession = applySession;

var _cookie = require("cookie");

var _nanoid = _interopRequireDefault(require("nanoid"));

var _memory = _interopRequireDefault(require("./store/memory"));

var _session = _interopRequireDefault(require("./session"));

var _cookie2 = _interopRequireDefault(require("./cookie"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function stringify(sess) {
  return JSON.stringify(sess, (key, val) => key === 'cookie' ? undefined : val);
}

function getOptions(opts = {}) {
  return {
    name: opts.name || 'sid',
    store: opts.store || new _memory.default(),
    generateId: opts.genid || opts.generateId || _nanoid.default,
    rolling: opts.rolling || false,
    touchAfter: opts.touchAfter ? opts.touchAfter : 0,
    cookie: opts.cookie || {},
    autoCommit: typeof opts.autoCommit !== 'undefined' ? opts.autoCommit : true
  };
}

async function applySession(req, res, opts) {
  const options = getOptions(opts);
  if (req.session) return;
  req._sessId = req.sessionId = req.headers && req.headers.cookie ? (0, _cookie.parse)(req.headers.cookie)[options.name] : null;
  req._sessOpts = options;
  req.sessionStore = options.store;

  if (req.sessionId) {
    const sess = await req.sessionStore.get(req.sessionId);

    if (sess) {
      req.session = new _session.default(req, res, sess);
      req.session.cookie = new _cookie2.default(sess.cookie);
    }
  }

  if (!req.session) {
    req.sessionId = options.generateId();
    req.session = new _session.default(req, res);
    req.session.cookie = new _cookie2.default(options.cookie);
  }

  req._sessStr = stringify(req.session); // autocommit

  if (options.autoCommit) {
    const oldEnd = res.end;

    res.end = async function resEndProxy(...args) {
      if (res.finished || res.writableEnded) return;
      if (req.session) await req.session.commit();
      oldEnd.apply(this, args);
    };
  }

  return req.session;
}