"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = withSession;

var _react = _interopRequireDefault(require("react"));

var _core = require("./core");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getDisplayName(WrappedComponent) {
  return WrappedComponent.displayName || WrappedComponent.name || "Component";
}

function withSession(handler, options) {
  // API Routes
  if (handler.length > 1) return async function WithSession(req, res) {
    await (0, _core.applySession)(req, res, options);
    return handler(req, res);
  }; // Pages

  const Page = handler;

  function WithSession(props) {
    return _react.default.createElement(Page, props);
  }

  WithSession.displayName = `withSession(${getDisplayName(Page)})`;

  if (Page.getInitialProps) {
    WithSession.getInitialProps = async pageCtx => {
      const ctx = "Component" in pageCtx ? pageCtx.ctx : pageCtx;

      if (typeof window === "undefined") {
        const {
          req,
          res
        } = ctx;
        await (0, _core.applySession)(req, res, options);
      }

      return Page.getInitialProps(ctx);
    };
  }

  return WithSession;
}